==> haskell-mustache-2.3.0-160-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-mustache.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: mustache
version: 2.3.0
id: mustache-2.3.0-3hB54vxHvPMI4EwQ0zkyCi
key: mustache-2.3.0-3hB54vxHvPMI4EwQ0zkyCi
license: BSD-3-Clause
copyright: (c) 2015,
           2016 Justus Adam
maintainer: dev@justus.science
author: Justus Adam
homepage: https://github.com/JustusAdam/mustache
synopsis: A mustache template parser library.
description:
    Allows parsing and rendering template files with mustache markup. See the
    mustache <http://mustache.github.io/mustache.5.html language reference>.
    .
    Implements the mustache spec version 1.1.3.
    .
    /Note/: Versions including and beyond 0.4 are compatible with ghc 7.8 again.
category: Development
abi: 630bd4785ff0d372fe56096081599bf7
exposed: True
exposed-modules:
    Text.Mustache Text.Mustache.Compile Text.Mustache.Parser
    Text.Mustache.Render Text.Mustache.Types
hidden-modules: Text.Mustache.Internal Text.Mustache.Internal.Types
                Paths_mustache
import-dirs: /usr/lib/ghc-8.6.4/site-local/mustache-2.3.0
library-dirs: /usr/lib/ghc-8.6.4/site-local/mustache-2.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/mustache-2.3.0
hs-libraries: HSmustache-2.3.0-3hB54vxHvPMI4EwQ0zkyCi
depends:
    aeson-1.4.2.0-DX8Ttq0Dq5cG6DT1joU4wl base-4.12.0.0
    bytestring-0.10.8.2 containers-0.6.0.1 directory-1.3.3.0
    either-5.0.1-LOhNT1jOlHM8vHN4ICWgxO filepath-1.4.2.1 mtl-2.2.2
    parsec-3.1.13.0 scientific-0.3.6.2-BVEhLkswVxa6jxFFJ9XwaR
    template-haskell-2.14.0.0 text-1.2.3.1
    th-lift-0.7.11-hZJVZ2zmXw59mRAYP9RXW
    unordered-containers-0.2.10.0-5bnYBnE7Vkj9Kd62fWith8
    vector-0.12.0.2-AoZ9EwUsgIW1yrOc105QXH
haddock-interfaces: /usr/share/doc/haskell-mustache/html/mustache.haddock
haddock-html: /usr/share/doc/haskell-mustache/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-mustache-2.3.0-161-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-mustache.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: mustache
version: 2.3.0
id: mustache-2.3.0-VjpwKVvhULEDWMPvmcuyG
key: mustache-2.3.0-VjpwKVvhULEDWMPvmcuyG
license: BSD-3-Clause
copyright: (c) 2015,
           2016 Justus Adam
maintainer: dev@justus.science
author: Justus Adam
homepage: https://github.com/JustusAdam/mustache
synopsis: A mustache template parser library.
description:
    Allows parsing and rendering template files with mustache markup. See the
    mustache <http://mustache.github.io/mustache.5.html language reference>.
    .
    Implements the mustache spec version 1.1.3.
    .
    /Note/: Versions including and beyond 0.4 are compatible with ghc 7.8 again.
category: Development
abi: eea0f8ec6514ab86d4c3a738d580410a
exposed: True
exposed-modules:
    Text.Mustache Text.Mustache.Compile Text.Mustache.Parser
    Text.Mustache.Render Text.Mustache.Types
hidden-modules: Text.Mustache.Internal Text.Mustache.Internal.Types
                Paths_mustache
import-dirs: /usr/lib/ghc-8.6.4/site-local/mustache-2.3.0
library-dirs: /usr/lib/ghc-8.6.4/site-local/mustache-2.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/mustache-2.3.0
hs-libraries: HSmustache-2.3.0-VjpwKVvhULEDWMPvmcuyG
depends:
    aeson-1.4.2.0-QHLwhPMHVB663aXnGqoMq base-4.12.0.0
    bytestring-0.10.8.2 containers-0.6.0.1 directory-1.3.3.0
    either-5.0.1-DlbOq2RXcZZ1IDN15z4kts filepath-1.4.2.1 mtl-2.2.2
    parsec-3.1.13.0 scientific-0.3.6.2-BVEhLkswVxa6jxFFJ9XwaR
    template-haskell-2.14.0.0 text-1.2.3.1
    th-lift-0.7.11-hZJVZ2zmXw59mRAYP9RXW
    unordered-containers-0.2.10.0-5bnYBnE7Vkj9Kd62fWith8
    vector-0.12.0.2-AoZ9EwUsgIW1yrOc105QXH
haddock-interfaces: /usr/share/doc/haskell-mustache/html/mustache.haddock
haddock-html: /usr/share/doc/haskell-mustache/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
